@@ -5,12 +5,13 @@ use super::*;
 /// Window layout effect handler
 #[derive(Debug)]
 pub struct UseWindowLayout<T> {
-    inner: UseWindowSize,
+    inner: UseWindow,
     bound: PhantomData<T>,
 }
 
 impl<T> UseWindowLayout<T> {
-    pub(crate) fn new(size: UseWindowSize) -> Self {
+    #[inline]
+    pub(crate) fn new(size: UseWindow) -> Self {
         Self { inner: size, bound: Default::default() }
     }
 }
@@ -20,8 +21,8 @@ where
     T: From<usize>,
 {
     /// get layout of current window
+    #[inline]
     pub fn get(&self) -> T {
         self.inner.layout()
-        // T::from(self.inner.x as usize)
     }
 }
