@@ -2,6 +2,8 @@
 #![deny(missing_debug_implementations)]
 #![deny(missing_copy_implementations)]
 #![doc = include_str!("../Readme.md")]
+#![doc(html_logo_url = "https://optimisticpeach.github.io/Logo.svg")]
+#![doc(html_favicon_url = "https://example.com/favicon.ico")]
 
 mod hooks;
 mod layouts;
